# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/permission_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/permission_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)fsai_grpc_api/protos/permission_api.proto\x1a fsai_grpc_api/protos/utils.proto\"7\n\nPermission\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0f\n\x07role_id\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\"@\n\x1d\x46indOrCreatePermissionRequest\x12\x1f\n\npermission\x18\x01 \x01(\x0b\x32\x0b.Permission\"c\n\x1e\x46indOrCreatePermissionResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1f\n\npermission\x18\x02 \x01(\x0b\x32\x0b.Permission\")\n\x16ListPermissionsRequest\x12\x0f\n\x07role_id\x18\x01 \x01(\x05\"]\n\x17ListPermissionsResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12 \n\x0bpermissions\x18\x02 \x03(\x0b\x32\x0b.Permission2\xb0\x01\n\rPermissionApi\x12Y\n\x16\x46indOrCreatePermission\x12\x1e.FindOrCreatePermissionRequest\x1a\x1f.FindOrCreatePermissionResponse\x12\x44\n\x0fListPermissions\x12\x17.ListPermissionsRequest\x1a\x18.ListPermissionsResponseb\x06proto3'
  ,
  dependencies=[fsai__grpc__api_dot_protos_dot_utils__pb2.DESCRIPTOR,])




_PERMISSION = _descriptor.Descriptor(
  name='Permission',
  full_name='Permission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Permission.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role_id', full_name='Permission.role_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='Permission.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=134,
)


_FINDORCREATEPERMISSIONREQUEST = _descriptor.Descriptor(
  name='FindOrCreatePermissionRequest',
  full_name='FindOrCreatePermissionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='permission', full_name='FindOrCreatePermissionRequest.permission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=136,
  serialized_end=200,
)


_FINDORCREATEPERMISSIONRESPONSE = _descriptor.Descriptor(
  name='FindOrCreatePermissionResponse',
  full_name='FindOrCreatePermissionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='FindOrCreatePermissionResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permission', full_name='FindOrCreatePermissionResponse.permission', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=202,
  serialized_end=301,
)


_LISTPERMISSIONSREQUEST = _descriptor.Descriptor(
  name='ListPermissionsRequest',
  full_name='ListPermissionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='role_id', full_name='ListPermissionsRequest.role_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=303,
  serialized_end=344,
)


_LISTPERMISSIONSRESPONSE = _descriptor.Descriptor(
  name='ListPermissionsResponse',
  full_name='ListPermissionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='ListPermissionsResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permissions', full_name='ListPermissionsResponse.permissions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=346,
  serialized_end=439,
)

_FINDORCREATEPERMISSIONREQUEST.fields_by_name['permission'].message_type = _PERMISSION
_FINDORCREATEPERMISSIONRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_FINDORCREATEPERMISSIONRESPONSE.fields_by_name['permission'].message_type = _PERMISSION
_LISTPERMISSIONSRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_LISTPERMISSIONSRESPONSE.fields_by_name['permissions'].message_type = _PERMISSION
DESCRIPTOR.message_types_by_name['Permission'] = _PERMISSION
DESCRIPTOR.message_types_by_name['FindOrCreatePermissionRequest'] = _FINDORCREATEPERMISSIONREQUEST
DESCRIPTOR.message_types_by_name['FindOrCreatePermissionResponse'] = _FINDORCREATEPERMISSIONRESPONSE
DESCRIPTOR.message_types_by_name['ListPermissionsRequest'] = _LISTPERMISSIONSREQUEST
DESCRIPTOR.message_types_by_name['ListPermissionsResponse'] = _LISTPERMISSIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Permission = _reflection.GeneratedProtocolMessageType('Permission', (_message.Message,), {
  'DESCRIPTOR' : _PERMISSION,
  '__module__' : 'fsai_grpc_api.protos.permission_api_pb2'
  # @@protoc_insertion_point(class_scope:Permission)
  })
_sym_db.RegisterMessage(Permission)

FindOrCreatePermissionRequest = _reflection.GeneratedProtocolMessageType('FindOrCreatePermissionRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATEPERMISSIONREQUEST,
  '__module__' : 'fsai_grpc_api.protos.permission_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreatePermissionRequest)
  })
_sym_db.RegisterMessage(FindOrCreatePermissionRequest)

FindOrCreatePermissionResponse = _reflection.GeneratedProtocolMessageType('FindOrCreatePermissionResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATEPERMISSIONRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.permission_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreatePermissionResponse)
  })
_sym_db.RegisterMessage(FindOrCreatePermissionResponse)

ListPermissionsRequest = _reflection.GeneratedProtocolMessageType('ListPermissionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPERMISSIONSREQUEST,
  '__module__' : 'fsai_grpc_api.protos.permission_api_pb2'
  # @@protoc_insertion_point(class_scope:ListPermissionsRequest)
  })
_sym_db.RegisterMessage(ListPermissionsRequest)

ListPermissionsResponse = _reflection.GeneratedProtocolMessageType('ListPermissionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPERMISSIONSRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.permission_api_pb2'
  # @@protoc_insertion_point(class_scope:ListPermissionsResponse)
  })
_sym_db.RegisterMessage(ListPermissionsResponse)



_PERMISSIONAPI = _descriptor.ServiceDescriptor(
  name='PermissionApi',
  full_name='PermissionApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=442,
  serialized_end=618,
  methods=[
  _descriptor.MethodDescriptor(
    name='FindOrCreatePermission',
    full_name='PermissionApi.FindOrCreatePermission',
    index=0,
    containing_service=None,
    input_type=_FINDORCREATEPERMISSIONREQUEST,
    output_type=_FINDORCREATEPERMISSIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListPermissions',
    full_name='PermissionApi.ListPermissions',
    index=1,
    containing_service=None,
    input_type=_LISTPERMISSIONSREQUEST,
    output_type=_LISTPERMISSIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PERMISSIONAPI)

DESCRIPTOR.services_by_name['PermissionApi'] = _PERMISSIONAPI

# @@protoc_insertion_point(module_scope)
