# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/workflow_analyzer_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/workflow_analyzer_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0fsai_grpc_api/protos/workflow_analyzer_api.proto\"M\n GetEstimatesByTotalAoiKm2Request\x12\x15\n\rtotal_aoi_km2\x18\x01 \x01(\x05\x12\x12\n\nbatch_size\x18\x02 \x01(\x05\"L\n GetEstimatesByTotalImagesRequest\x12\x14\n\x0ctotal_images\x18\x01 \x01(\x05\x12\x12\n\nbatch_size\x18\x02 \x01(\x05\"4\n\x1eGetEstimatesByMissionIdRequest\x12\x12\n\nmission_id\x18\x01 \x01(\x05\"v\n\x14WorkflowAnalyzerCost\x12\x1b\n\x13\x66\x65\x61ture_acquisition\x18\x01 \x01(\x02\x12\x19\n\x11image_acquisition\x18\x02 \x01(\x02\x12\x17\n\x0fimage_inference\x18\x03 \x01(\x02\x12\r\n\x05total\x18\x04 \x01(\x02\"w\n\x15WorkflowAnalyzerHours\x12\x1b\n\x13\x66\x65\x61ture_acquisition\x18\x01 \x01(\x02\x12\x19\n\x11image_acquisition\x18\x02 \x01(\x02\x12\x17\n\x0fimage_inference\x18\x03 \x01(\x02\x12\r\n\x05total\x18\x04 \x01(\x02\"|\n\x18WorkflowAnalyzerResponse\x12\x14\n\x0c\x62\x61tch_number\x18\x01 \x01(\x05\x12#\n\x04\x63ost\x18\x05 \x01(\x0b\x32\x15.WorkflowAnalyzerCost\x12%\n\x05hours\x18\x06 \x01(\x0b\x32\x16.WorkflowAnalyzerHours2\xa2\x02\n\x13WorkflowAnalyzerApi\x12Y\n\x19GetEstimatesByTotalAoiKm2\x12!.GetEstimatesByTotalAoiKm2Request\x1a\x19.WorkflowAnalyzerResponse\x12Y\n\x19GetEstimatesByTotalImages\x12!.GetEstimatesByTotalImagesRequest\x1a\x19.WorkflowAnalyzerResponse\x12U\n\x17GetEstimatesByMissionId\x12\x1f.GetEstimatesByMissionIdRequest\x1a\x19.WorkflowAnalyzerResponseb\x06proto3'
)




_GETESTIMATESBYTOTALAOIKM2REQUEST = _descriptor.Descriptor(
  name='GetEstimatesByTotalAoiKm2Request',
  full_name='GetEstimatesByTotalAoiKm2Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_aoi_km2', full_name='GetEstimatesByTotalAoiKm2Request.total_aoi_km2', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_size', full_name='GetEstimatesByTotalAoiKm2Request.batch_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52,
  serialized_end=129,
)


_GETESTIMATESBYTOTALIMAGESREQUEST = _descriptor.Descriptor(
  name='GetEstimatesByTotalImagesRequest',
  full_name='GetEstimatesByTotalImagesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_images', full_name='GetEstimatesByTotalImagesRequest.total_images', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_size', full_name='GetEstimatesByTotalImagesRequest.batch_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=131,
  serialized_end=207,
)


_GETESTIMATESBYMISSIONIDREQUEST = _descriptor.Descriptor(
  name='GetEstimatesByMissionIdRequest',
  full_name='GetEstimatesByMissionIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission_id', full_name='GetEstimatesByMissionIdRequest.mission_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=261,
)


_WORKFLOWANALYZERCOST = _descriptor.Descriptor(
  name='WorkflowAnalyzerCost',
  full_name='WorkflowAnalyzerCost',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_acquisition', full_name='WorkflowAnalyzerCost.feature_acquisition', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_acquisition', full_name='WorkflowAnalyzerCost.image_acquisition', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_inference', full_name='WorkflowAnalyzerCost.image_inference', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total', full_name='WorkflowAnalyzerCost.total', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=381,
)


_WORKFLOWANALYZERHOURS = _descriptor.Descriptor(
  name='WorkflowAnalyzerHours',
  full_name='WorkflowAnalyzerHours',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_acquisition', full_name='WorkflowAnalyzerHours.feature_acquisition', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_acquisition', full_name='WorkflowAnalyzerHours.image_acquisition', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_inference', full_name='WorkflowAnalyzerHours.image_inference', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total', full_name='WorkflowAnalyzerHours.total', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=383,
  serialized_end=502,
)


_WORKFLOWANALYZERRESPONSE = _descriptor.Descriptor(
  name='WorkflowAnalyzerResponse',
  full_name='WorkflowAnalyzerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='batch_number', full_name='WorkflowAnalyzerResponse.batch_number', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cost', full_name='WorkflowAnalyzerResponse.cost', index=1,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hours', full_name='WorkflowAnalyzerResponse.hours', index=2,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=504,
  serialized_end=628,
)

_WORKFLOWANALYZERRESPONSE.fields_by_name['cost'].message_type = _WORKFLOWANALYZERCOST
_WORKFLOWANALYZERRESPONSE.fields_by_name['hours'].message_type = _WORKFLOWANALYZERHOURS
DESCRIPTOR.message_types_by_name['GetEstimatesByTotalAoiKm2Request'] = _GETESTIMATESBYTOTALAOIKM2REQUEST
DESCRIPTOR.message_types_by_name['GetEstimatesByTotalImagesRequest'] = _GETESTIMATESBYTOTALIMAGESREQUEST
DESCRIPTOR.message_types_by_name['GetEstimatesByMissionIdRequest'] = _GETESTIMATESBYMISSIONIDREQUEST
DESCRIPTOR.message_types_by_name['WorkflowAnalyzerCost'] = _WORKFLOWANALYZERCOST
DESCRIPTOR.message_types_by_name['WorkflowAnalyzerHours'] = _WORKFLOWANALYZERHOURS
DESCRIPTOR.message_types_by_name['WorkflowAnalyzerResponse'] = _WORKFLOWANALYZERRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetEstimatesByTotalAoiKm2Request = _reflection.GeneratedProtocolMessageType('GetEstimatesByTotalAoiKm2Request', (_message.Message,), {
  'DESCRIPTOR' : _GETESTIMATESBYTOTALAOIKM2REQUEST,
  '__module__' : 'fsai_grpc_api.protos.workflow_analyzer_api_pb2'
  # @@protoc_insertion_point(class_scope:GetEstimatesByTotalAoiKm2Request)
  })
_sym_db.RegisterMessage(GetEstimatesByTotalAoiKm2Request)

GetEstimatesByTotalImagesRequest = _reflection.GeneratedProtocolMessageType('GetEstimatesByTotalImagesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETESTIMATESBYTOTALIMAGESREQUEST,
  '__module__' : 'fsai_grpc_api.protos.workflow_analyzer_api_pb2'
  # @@protoc_insertion_point(class_scope:GetEstimatesByTotalImagesRequest)
  })
_sym_db.RegisterMessage(GetEstimatesByTotalImagesRequest)

GetEstimatesByMissionIdRequest = _reflection.GeneratedProtocolMessageType('GetEstimatesByMissionIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETESTIMATESBYMISSIONIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.workflow_analyzer_api_pb2'
  # @@protoc_insertion_point(class_scope:GetEstimatesByMissionIdRequest)
  })
_sym_db.RegisterMessage(GetEstimatesByMissionIdRequest)

WorkflowAnalyzerCost = _reflection.GeneratedProtocolMessageType('WorkflowAnalyzerCost', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWANALYZERCOST,
  '__module__' : 'fsai_grpc_api.protos.workflow_analyzer_api_pb2'
  # @@protoc_insertion_point(class_scope:WorkflowAnalyzerCost)
  })
_sym_db.RegisterMessage(WorkflowAnalyzerCost)

WorkflowAnalyzerHours = _reflection.GeneratedProtocolMessageType('WorkflowAnalyzerHours', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWANALYZERHOURS,
  '__module__' : 'fsai_grpc_api.protos.workflow_analyzer_api_pb2'
  # @@protoc_insertion_point(class_scope:WorkflowAnalyzerHours)
  })
_sym_db.RegisterMessage(WorkflowAnalyzerHours)

WorkflowAnalyzerResponse = _reflection.GeneratedProtocolMessageType('WorkflowAnalyzerResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWANALYZERRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.workflow_analyzer_api_pb2'
  # @@protoc_insertion_point(class_scope:WorkflowAnalyzerResponse)
  })
_sym_db.RegisterMessage(WorkflowAnalyzerResponse)



_WORKFLOWANALYZERAPI = _descriptor.ServiceDescriptor(
  name='WorkflowAnalyzerApi',
  full_name='WorkflowAnalyzerApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=631,
  serialized_end=921,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetEstimatesByTotalAoiKm2',
    full_name='WorkflowAnalyzerApi.GetEstimatesByTotalAoiKm2',
    index=0,
    containing_service=None,
    input_type=_GETESTIMATESBYTOTALAOIKM2REQUEST,
    output_type=_WORKFLOWANALYZERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetEstimatesByTotalImages',
    full_name='WorkflowAnalyzerApi.GetEstimatesByTotalImages',
    index=1,
    containing_service=None,
    input_type=_GETESTIMATESBYTOTALIMAGESREQUEST,
    output_type=_WORKFLOWANALYZERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetEstimatesByMissionId',
    full_name='WorkflowAnalyzerApi.GetEstimatesByMissionId',
    index=2,
    containing_service=None,
    input_type=_GETESTIMATESBYMISSIONIDREQUEST,
    output_type=_WORKFLOWANALYZERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_WORKFLOWANALYZERAPI)

DESCRIPTOR.services_by_name['WorkflowAnalyzerApi'] = _WORKFLOWANALYZERAPI

# @@protoc_insertion_point(module_scope)
