# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/mission_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/mission_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&fsai_grpc_api/protos/mission_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a fsai_grpc_api/protos/utils.proto\"\x98\x01\n\x07Mission\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"1\n\x14\x43reateMissionRequest\x12\x19\n\x07mission\x18\x01 \x01(\x0b\x32\x08.Mission\"T\n\x15\x43reateMissionResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x19\n\x07mission\x18\x02 \x01(\x0b\x32\x08.Mission\"0\n\x13ListMissionsRequest\x12\x19\n\x07mission\x18\x01 \x01(\x0b\x32\x08.Mission\"T\n\x14ListMissionsResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1a\n\x08missions\x18\x02 \x03(\x0b\x32\x08.Mission\"3\n\x16\x46indMissionByIdRequest\x12\x19\n\x07mission\x18\x01 \x01(\x0b\x32\x08.Mission\"V\n\x17\x46indMissionByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x19\n\x07mission\x18\x02 \x01(\x0b\x32\x08.Mission\"=\n LockMissionAreaOfInterestRequest\x12\x19\n\x07mission\x18\x01 \x01(\x0b\x32\x08.Mission\"`\n!LockMissionAreaOfInterestResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x19\n\x07mission\x18\x02 \x01(\x0b\x32\x08.Mission\"1\n\x14\x44\x65leteMissionRequest\x12\x19\n\x07mission\x18\x01 \x01(\x0b\x32\x08.Mission\"T\n\x15\x44\x65leteMissionResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x19\n\x07mission\x18\x02 \x01(\x0b\x32\x08.Mission\"5\n\x18UpdateMissionByIdRequest\x12\x19\n\x07mission\x18\x01 \x01(\x0b\x32\x08.Mission\"X\n\x19UpdateMissionByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x19\n\x07mission\x18\x02 \x01(\x0b\x32\x08.Mission2\xbf\x03\n\nMissionApi\x12>\n\rCreateMission\x12\x15.CreateMissionRequest\x1a\x16.CreateMissionResponse\x12;\n\x0cListMissions\x12\x14.ListMissionsRequest\x1a\x15.ListMissionsResponse\x12\x44\n\x0f\x46indMissionById\x12\x17.FindMissionByIdRequest\x1a\x18.FindMissionByIdResponse\x12\x62\n\x19LockMissionAreaOfInterest\x12!.LockMissionAreaOfInterestRequest\x1a\".LockMissionAreaOfInterestResponse\x12>\n\rDeleteMission\x12\x15.DeleteMissionRequest\x1a\x16.DeleteMissionResponse\x12J\n\x11UpdateMissionById\x12\x19.UpdateMissionByIdRequest\x1a\x1a.UpdateMissionByIdResponseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,fsai__grpc__api_dot_protos_dot_utils__pb2.DESCRIPTOR,])




_MISSION = _descriptor.Descriptor(
  name='Mission',
  full_name='Mission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Mission.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='Mission.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='Mission.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='Mission.created_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='Mission.updated_at', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=110,
  serialized_end=262,
)


_CREATEMISSIONREQUEST = _descriptor.Descriptor(
  name='CreateMissionRequest',
  full_name='CreateMissionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission', full_name='CreateMissionRequest.mission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=264,
  serialized_end=313,
)


_CREATEMISSIONRESPONSE = _descriptor.Descriptor(
  name='CreateMissionResponse',
  full_name='CreateMissionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='CreateMissionResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission', full_name='CreateMissionResponse.mission', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=315,
  serialized_end=399,
)


_LISTMISSIONSREQUEST = _descriptor.Descriptor(
  name='ListMissionsRequest',
  full_name='ListMissionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission', full_name='ListMissionsRequest.mission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=401,
  serialized_end=449,
)


_LISTMISSIONSRESPONSE = _descriptor.Descriptor(
  name='ListMissionsResponse',
  full_name='ListMissionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='ListMissionsResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='missions', full_name='ListMissionsResponse.missions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=451,
  serialized_end=535,
)


_FINDMISSIONBYIDREQUEST = _descriptor.Descriptor(
  name='FindMissionByIdRequest',
  full_name='FindMissionByIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission', full_name='FindMissionByIdRequest.mission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=537,
  serialized_end=588,
)


_FINDMISSIONBYIDRESPONSE = _descriptor.Descriptor(
  name='FindMissionByIdResponse',
  full_name='FindMissionByIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='FindMissionByIdResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission', full_name='FindMissionByIdResponse.mission', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=590,
  serialized_end=676,
)


_LOCKMISSIONAREAOFINTERESTREQUEST = _descriptor.Descriptor(
  name='LockMissionAreaOfInterestRequest',
  full_name='LockMissionAreaOfInterestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission', full_name='LockMissionAreaOfInterestRequest.mission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=678,
  serialized_end=739,
)


_LOCKMISSIONAREAOFINTERESTRESPONSE = _descriptor.Descriptor(
  name='LockMissionAreaOfInterestResponse',
  full_name='LockMissionAreaOfInterestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='LockMissionAreaOfInterestResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission', full_name='LockMissionAreaOfInterestResponse.mission', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=741,
  serialized_end=837,
)


_DELETEMISSIONREQUEST = _descriptor.Descriptor(
  name='DeleteMissionRequest',
  full_name='DeleteMissionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission', full_name='DeleteMissionRequest.mission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=839,
  serialized_end=888,
)


_DELETEMISSIONRESPONSE = _descriptor.Descriptor(
  name='DeleteMissionResponse',
  full_name='DeleteMissionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='DeleteMissionResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission', full_name='DeleteMissionResponse.mission', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=890,
  serialized_end=974,
)


_UPDATEMISSIONBYIDREQUEST = _descriptor.Descriptor(
  name='UpdateMissionByIdRequest',
  full_name='UpdateMissionByIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission', full_name='UpdateMissionByIdRequest.mission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=976,
  serialized_end=1029,
)


_UPDATEMISSIONBYIDRESPONSE = _descriptor.Descriptor(
  name='UpdateMissionByIdResponse',
  full_name='UpdateMissionByIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='UpdateMissionByIdResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission', full_name='UpdateMissionByIdResponse.mission', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1031,
  serialized_end=1119,
)

_MISSION.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MISSION.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CREATEMISSIONREQUEST.fields_by_name['mission'].message_type = _MISSION
_CREATEMISSIONRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_CREATEMISSIONRESPONSE.fields_by_name['mission'].message_type = _MISSION
_LISTMISSIONSREQUEST.fields_by_name['mission'].message_type = _MISSION
_LISTMISSIONSRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_LISTMISSIONSRESPONSE.fields_by_name['missions'].message_type = _MISSION
_FINDMISSIONBYIDREQUEST.fields_by_name['mission'].message_type = _MISSION
_FINDMISSIONBYIDRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_FINDMISSIONBYIDRESPONSE.fields_by_name['mission'].message_type = _MISSION
_LOCKMISSIONAREAOFINTERESTREQUEST.fields_by_name['mission'].message_type = _MISSION
_LOCKMISSIONAREAOFINTERESTRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_LOCKMISSIONAREAOFINTERESTRESPONSE.fields_by_name['mission'].message_type = _MISSION
_DELETEMISSIONREQUEST.fields_by_name['mission'].message_type = _MISSION
_DELETEMISSIONRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_DELETEMISSIONRESPONSE.fields_by_name['mission'].message_type = _MISSION
_UPDATEMISSIONBYIDREQUEST.fields_by_name['mission'].message_type = _MISSION
_UPDATEMISSIONBYIDRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_UPDATEMISSIONBYIDRESPONSE.fields_by_name['mission'].message_type = _MISSION
DESCRIPTOR.message_types_by_name['Mission'] = _MISSION
DESCRIPTOR.message_types_by_name['CreateMissionRequest'] = _CREATEMISSIONREQUEST
DESCRIPTOR.message_types_by_name['CreateMissionResponse'] = _CREATEMISSIONRESPONSE
DESCRIPTOR.message_types_by_name['ListMissionsRequest'] = _LISTMISSIONSREQUEST
DESCRIPTOR.message_types_by_name['ListMissionsResponse'] = _LISTMISSIONSRESPONSE
DESCRIPTOR.message_types_by_name['FindMissionByIdRequest'] = _FINDMISSIONBYIDREQUEST
DESCRIPTOR.message_types_by_name['FindMissionByIdResponse'] = _FINDMISSIONBYIDRESPONSE
DESCRIPTOR.message_types_by_name['LockMissionAreaOfInterestRequest'] = _LOCKMISSIONAREAOFINTERESTREQUEST
DESCRIPTOR.message_types_by_name['LockMissionAreaOfInterestResponse'] = _LOCKMISSIONAREAOFINTERESTRESPONSE
DESCRIPTOR.message_types_by_name['DeleteMissionRequest'] = _DELETEMISSIONREQUEST
DESCRIPTOR.message_types_by_name['DeleteMissionResponse'] = _DELETEMISSIONRESPONSE
DESCRIPTOR.message_types_by_name['UpdateMissionByIdRequest'] = _UPDATEMISSIONBYIDREQUEST
DESCRIPTOR.message_types_by_name['UpdateMissionByIdResponse'] = _UPDATEMISSIONBYIDRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Mission = _reflection.GeneratedProtocolMessageType('Mission', (_message.Message,), {
  'DESCRIPTOR' : _MISSION,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:Mission)
  })
_sym_db.RegisterMessage(Mission)

CreateMissionRequest = _reflection.GeneratedProtocolMessageType('CreateMissionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMISSIONREQUEST,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:CreateMissionRequest)
  })
_sym_db.RegisterMessage(CreateMissionRequest)

CreateMissionResponse = _reflection.GeneratedProtocolMessageType('CreateMissionResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMISSIONRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:CreateMissionResponse)
  })
_sym_db.RegisterMessage(CreateMissionResponse)

ListMissionsRequest = _reflection.GeneratedProtocolMessageType('ListMissionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMISSIONSREQUEST,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:ListMissionsRequest)
  })
_sym_db.RegisterMessage(ListMissionsRequest)

ListMissionsResponse = _reflection.GeneratedProtocolMessageType('ListMissionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMISSIONSRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:ListMissionsResponse)
  })
_sym_db.RegisterMessage(ListMissionsResponse)

FindMissionByIdRequest = _reflection.GeneratedProtocolMessageType('FindMissionByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDMISSIONBYIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:FindMissionByIdRequest)
  })
_sym_db.RegisterMessage(FindMissionByIdRequest)

FindMissionByIdResponse = _reflection.GeneratedProtocolMessageType('FindMissionByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDMISSIONBYIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:FindMissionByIdResponse)
  })
_sym_db.RegisterMessage(FindMissionByIdResponse)

LockMissionAreaOfInterestRequest = _reflection.GeneratedProtocolMessageType('LockMissionAreaOfInterestRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKMISSIONAREAOFINTERESTREQUEST,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:LockMissionAreaOfInterestRequest)
  })
_sym_db.RegisterMessage(LockMissionAreaOfInterestRequest)

LockMissionAreaOfInterestResponse = _reflection.GeneratedProtocolMessageType('LockMissionAreaOfInterestResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOCKMISSIONAREAOFINTERESTRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:LockMissionAreaOfInterestResponse)
  })
_sym_db.RegisterMessage(LockMissionAreaOfInterestResponse)

DeleteMissionRequest = _reflection.GeneratedProtocolMessageType('DeleteMissionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMISSIONREQUEST,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:DeleteMissionRequest)
  })
_sym_db.RegisterMessage(DeleteMissionRequest)

DeleteMissionResponse = _reflection.GeneratedProtocolMessageType('DeleteMissionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMISSIONRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:DeleteMissionResponse)
  })
_sym_db.RegisterMessage(DeleteMissionResponse)

UpdateMissionByIdRequest = _reflection.GeneratedProtocolMessageType('UpdateMissionByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMISSIONBYIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:UpdateMissionByIdRequest)
  })
_sym_db.RegisterMessage(UpdateMissionByIdRequest)

UpdateMissionByIdResponse = _reflection.GeneratedProtocolMessageType('UpdateMissionByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMISSIONBYIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:UpdateMissionByIdResponse)
  })
_sym_db.RegisterMessage(UpdateMissionByIdResponse)



_MISSIONAPI = _descriptor.ServiceDescriptor(
  name='MissionApi',
  full_name='MissionApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1122,
  serialized_end=1569,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateMission',
    full_name='MissionApi.CreateMission',
    index=0,
    containing_service=None,
    input_type=_CREATEMISSIONREQUEST,
    output_type=_CREATEMISSIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListMissions',
    full_name='MissionApi.ListMissions',
    index=1,
    containing_service=None,
    input_type=_LISTMISSIONSREQUEST,
    output_type=_LISTMISSIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FindMissionById',
    full_name='MissionApi.FindMissionById',
    index=2,
    containing_service=None,
    input_type=_FINDMISSIONBYIDREQUEST,
    output_type=_FINDMISSIONBYIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LockMissionAreaOfInterest',
    full_name='MissionApi.LockMissionAreaOfInterest',
    index=3,
    containing_service=None,
    input_type=_LOCKMISSIONAREAOFINTERESTREQUEST,
    output_type=_LOCKMISSIONAREAOFINTERESTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteMission',
    full_name='MissionApi.DeleteMission',
    index=4,
    containing_service=None,
    input_type=_DELETEMISSIONREQUEST,
    output_type=_DELETEMISSIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateMissionById',
    full_name='MissionApi.UpdateMissionById',
    index=5,
    containing_service=None,
    input_type=_UPDATEMISSIONBYIDREQUEST,
    output_type=_UPDATEMISSIONBYIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MISSIONAPI)

DESCRIPTOR.services_by_name['MissionApi'] = _MISSIONAPI

# @@protoc_insertion_point(module_scope)
