# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/team_member_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/team_member_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*fsai_grpc_api/protos/team_member_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a fsai_grpc_api/protos/utils.proto\"\xca\x01\n\nTeamMember\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0f\n\x07user_id\x18\x02 \x01(\x05\x12\x0f\n\x07team_id\x18\x03 \x01(\x05\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ndeleted_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"A\n\x1d\x46indOrCreateTeamMemberRequest\x12 \n\x0bteam_member\x18\x01 \x01(\x0b\x32\x0b.TeamMember\"d\n\x1e\x46indOrCreateTeamMemberResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12 \n\x0bteam_member\x18\x02 \x01(\x0b\x32\x0b.TeamMember2j\n\rTeamMemberApi\x12Y\n\x16\x46indOrCreateTeamMember\x12\x1e.FindOrCreateTeamMemberRequest\x1a\x1f.FindOrCreateTeamMemberResponseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,fsai__grpc__api_dot_protos_dot_utils__pb2.DESCRIPTOR,])




_TEAMMEMBER = _descriptor.Descriptor(
  name='TeamMember',
  full_name='TeamMember',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='TeamMember.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='TeamMember.user_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='TeamMember.team_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='TeamMember.created_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='TeamMember.updated_at', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deleted_at', full_name='TeamMember.deleted_at', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=316,
)


_FINDORCREATETEAMMEMBERREQUEST = _descriptor.Descriptor(
  name='FindOrCreateTeamMemberRequest',
  full_name='FindOrCreateTeamMemberRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='team_member', full_name='FindOrCreateTeamMemberRequest.team_member', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=318,
  serialized_end=383,
)


_FINDORCREATETEAMMEMBERRESPONSE = _descriptor.Descriptor(
  name='FindOrCreateTeamMemberResponse',
  full_name='FindOrCreateTeamMemberResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='FindOrCreateTeamMemberResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='team_member', full_name='FindOrCreateTeamMemberResponse.team_member', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=385,
  serialized_end=485,
)

_TEAMMEMBER.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TEAMMEMBER.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TEAMMEMBER.fields_by_name['deleted_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FINDORCREATETEAMMEMBERREQUEST.fields_by_name['team_member'].message_type = _TEAMMEMBER
_FINDORCREATETEAMMEMBERRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_FINDORCREATETEAMMEMBERRESPONSE.fields_by_name['team_member'].message_type = _TEAMMEMBER
DESCRIPTOR.message_types_by_name['TeamMember'] = _TEAMMEMBER
DESCRIPTOR.message_types_by_name['FindOrCreateTeamMemberRequest'] = _FINDORCREATETEAMMEMBERREQUEST
DESCRIPTOR.message_types_by_name['FindOrCreateTeamMemberResponse'] = _FINDORCREATETEAMMEMBERRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TeamMember = _reflection.GeneratedProtocolMessageType('TeamMember', (_message.Message,), {
  'DESCRIPTOR' : _TEAMMEMBER,
  '__module__' : 'fsai_grpc_api.protos.team_member_api_pb2'
  # @@protoc_insertion_point(class_scope:TeamMember)
  })
_sym_db.RegisterMessage(TeamMember)

FindOrCreateTeamMemberRequest = _reflection.GeneratedProtocolMessageType('FindOrCreateTeamMemberRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATETEAMMEMBERREQUEST,
  '__module__' : 'fsai_grpc_api.protos.team_member_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateTeamMemberRequest)
  })
_sym_db.RegisterMessage(FindOrCreateTeamMemberRequest)

FindOrCreateTeamMemberResponse = _reflection.GeneratedProtocolMessageType('FindOrCreateTeamMemberResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATETEAMMEMBERRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.team_member_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateTeamMemberResponse)
  })
_sym_db.RegisterMessage(FindOrCreateTeamMemberResponse)



_TEAMMEMBERAPI = _descriptor.ServiceDescriptor(
  name='TeamMemberApi',
  full_name='TeamMemberApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=487,
  serialized_end=593,
  methods=[
  _descriptor.MethodDescriptor(
    name='FindOrCreateTeamMember',
    full_name='TeamMemberApi.FindOrCreateTeamMember',
    index=0,
    containing_service=None,
    input_type=_FINDORCREATETEAMMEMBERREQUEST,
    output_type=_FINDORCREATETEAMMEMBERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TEAMMEMBERAPI)

DESCRIPTOR.services_by_name['TeamMemberApi'] = _TEAMMEMBERAPI

# @@protoc_insertion_point(module_scope)
