# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/workflow_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/workflow_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'fsai_grpc_api/protos/workflow_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a fsai_grpc_api/protos/utils.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xe1\x01\n\x08Workflow\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nmission_id\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x08metadata\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\".\n\x0fWorkflowRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"Q\n\x10WorkflowResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x08workflow\x18\x02 \x01(\x0b\x32\t.Workflow\">\n\x1fTransitionWorkflowStatusRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"a\n TransitionWorkflowStatusResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x08workflow\x18\x02 \x01(\x0b\x32\t.Workflow\"6\n\x17QueueMissionScanRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"Y\n\x18QueueMissionScanResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x08workflow\x18\x02 \x01(\x0b\x32\t.Workflow\"`\n\x1eListQueuedMissionScansResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1c\n\tworkflows\x18\x02 \x03(\x0b\x32\t.Workflow\"6\n\x17ListMissionScansRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"Z\n\x18ListMissionScansResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1c\n\tworkflows\x18\x02 \x03(\x0b\x32\t.Workflow\"A\n\"ListRelatedMissionScansByIdRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"e\n#ListRelatedMissionScansByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1c\n\tworkflows\x18\x02 \x03(\x0b\x32\t.Workflow\"8\n\x19QueueMissionExportRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"[\n\x1aQueueMissionExportResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x08workflow\x18\x02 \x01(\x0b\x32\t.Workflow\"b\n ListQueuedMissionExportsResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1c\n\tworkflows\x18\x02 \x03(\x0b\x32\t.Workflow\"8\n\x19ListMissionExportsRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"\\\n\x1aListMissionExportsResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1c\n\tworkflows\x18\x02 \x03(\x0b\x32\t.Workflow\"4\n\x15\x44\x65leteWorkflowRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"W\n\x16\x44\x65leteWorkflowResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x08workflow\x18\x02 \x01(\x0b\x32\t.Workflow2\xb2\x06\n\x0bWorkflowApi\x12;\n\x14\x46indOrCreateWorkflow\x12\x10.WorkflowRequest\x1a\x11.WorkflowResponse\x12_\n\x18TransitionWorkflowStatus\x12 .TransitionWorkflowStatusRequest\x1a!.TransitionWorkflowStatusResponse\x12\x41\n\x0e\x44\x65leteWorkflow\x12\x16.DeleteWorkflowRequest\x1a\x17.DeleteWorkflowResponse\x12M\n\x12QueueMissionExport\x12\x1a.QueueMissionExportRequest\x1a\x1b.QueueMissionExportResponse\x12U\n\x18ListQueuedMissionExports\x12\x16.google.protobuf.Empty\x1a!.ListQueuedMissionExportsResponse\x12M\n\x12ListMissionExports\x12\x1a.ListMissionExportsRequest\x1a\x1b.ListMissionExportsResponse\x12G\n\x10QueueMissionScan\x12\x18.QueueMissionScanRequest\x1a\x19.QueueMissionScanResponse\x12Q\n\x16ListQueuedMissionScans\x12\x16.google.protobuf.Empty\x1a\x1f.ListQueuedMissionScansResponse\x12G\n\x10ListMissionScans\x12\x18.ListMissionScansRequest\x1a\x19.ListMissionScansResponse\x12h\n\x1bListRelatedMissionScansById\x12#.ListRelatedMissionScansByIdRequest\x1a$.ListRelatedMissionScansByIdResponseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,fsai__grpc__api_dot_protos_dot_utils__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,])




_WORKFLOW = _descriptor.Descriptor(
  name='Workflow',
  full_name='Workflow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Workflow.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission_id', full_name='Workflow.mission_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='Workflow.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='Workflow.type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='Workflow.status', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='Workflow.created_at', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='Workflow.updated_at', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='Workflow.metadata', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=170,
  serialized_end=395,
)


_WORKFLOWREQUEST = _descriptor.Descriptor(
  name='WorkflowRequest',
  full_name='WorkflowRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workflow', full_name='WorkflowRequest.workflow', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=397,
  serialized_end=443,
)


_WORKFLOWRESPONSE = _descriptor.Descriptor(
  name='WorkflowResponse',
  full_name='WorkflowResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='WorkflowResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow', full_name='WorkflowResponse.workflow', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=445,
  serialized_end=526,
)


_TRANSITIONWORKFLOWSTATUSREQUEST = _descriptor.Descriptor(
  name='TransitionWorkflowStatusRequest',
  full_name='TransitionWorkflowStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workflow', full_name='TransitionWorkflowStatusRequest.workflow', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=528,
  serialized_end=590,
)


_TRANSITIONWORKFLOWSTATUSRESPONSE = _descriptor.Descriptor(
  name='TransitionWorkflowStatusResponse',
  full_name='TransitionWorkflowStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='TransitionWorkflowStatusResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow', full_name='TransitionWorkflowStatusResponse.workflow', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=592,
  serialized_end=689,
)


_QUEUEMISSIONSCANREQUEST = _descriptor.Descriptor(
  name='QueueMissionScanRequest',
  full_name='QueueMissionScanRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workflow', full_name='QueueMissionScanRequest.workflow', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=691,
  serialized_end=745,
)


_QUEUEMISSIONSCANRESPONSE = _descriptor.Descriptor(
  name='QueueMissionScanResponse',
  full_name='QueueMissionScanResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='QueueMissionScanResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow', full_name='QueueMissionScanResponse.workflow', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=747,
  serialized_end=836,
)


_LISTQUEUEDMISSIONSCANSRESPONSE = _descriptor.Descriptor(
  name='ListQueuedMissionScansResponse',
  full_name='ListQueuedMissionScansResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='ListQueuedMissionScansResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflows', full_name='ListQueuedMissionScansResponse.workflows', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=838,
  serialized_end=934,
)


_LISTMISSIONSCANSREQUEST = _descriptor.Descriptor(
  name='ListMissionScansRequest',
  full_name='ListMissionScansRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workflow', full_name='ListMissionScansRequest.workflow', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=936,
  serialized_end=990,
)


_LISTMISSIONSCANSRESPONSE = _descriptor.Descriptor(
  name='ListMissionScansResponse',
  full_name='ListMissionScansResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='ListMissionScansResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflows', full_name='ListMissionScansResponse.workflows', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=992,
  serialized_end=1082,
)


_LISTRELATEDMISSIONSCANSBYIDREQUEST = _descriptor.Descriptor(
  name='ListRelatedMissionScansByIdRequest',
  full_name='ListRelatedMissionScansByIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workflow', full_name='ListRelatedMissionScansByIdRequest.workflow', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1084,
  serialized_end=1149,
)


_LISTRELATEDMISSIONSCANSBYIDRESPONSE = _descriptor.Descriptor(
  name='ListRelatedMissionScansByIdResponse',
  full_name='ListRelatedMissionScansByIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='ListRelatedMissionScansByIdResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflows', full_name='ListRelatedMissionScansByIdResponse.workflows', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1151,
  serialized_end=1252,
)


_QUEUEMISSIONEXPORTREQUEST = _descriptor.Descriptor(
  name='QueueMissionExportRequest',
  full_name='QueueMissionExportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workflow', full_name='QueueMissionExportRequest.workflow', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1254,
  serialized_end=1310,
)


_QUEUEMISSIONEXPORTRESPONSE = _descriptor.Descriptor(
  name='QueueMissionExportResponse',
  full_name='QueueMissionExportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='QueueMissionExportResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow', full_name='QueueMissionExportResponse.workflow', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1312,
  serialized_end=1403,
)


_LISTQUEUEDMISSIONEXPORTSRESPONSE = _descriptor.Descriptor(
  name='ListQueuedMissionExportsResponse',
  full_name='ListQueuedMissionExportsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='ListQueuedMissionExportsResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflows', full_name='ListQueuedMissionExportsResponse.workflows', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1405,
  serialized_end=1503,
)


_LISTMISSIONEXPORTSREQUEST = _descriptor.Descriptor(
  name='ListMissionExportsRequest',
  full_name='ListMissionExportsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workflow', full_name='ListMissionExportsRequest.workflow', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1505,
  serialized_end=1561,
)


_LISTMISSIONEXPORTSRESPONSE = _descriptor.Descriptor(
  name='ListMissionExportsResponse',
  full_name='ListMissionExportsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='ListMissionExportsResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflows', full_name='ListMissionExportsResponse.workflows', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1563,
  serialized_end=1655,
)


_DELETEWORKFLOWREQUEST = _descriptor.Descriptor(
  name='DeleteWorkflowRequest',
  full_name='DeleteWorkflowRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workflow', full_name='DeleteWorkflowRequest.workflow', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1657,
  serialized_end=1709,
)


_DELETEWORKFLOWRESPONSE = _descriptor.Descriptor(
  name='DeleteWorkflowResponse',
  full_name='DeleteWorkflowResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='DeleteWorkflowResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow', full_name='DeleteWorkflowResponse.workflow', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1711,
  serialized_end=1798,
)

_WORKFLOW.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_WORKFLOW.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_WORKFLOW.fields_by_name['metadata'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_WORKFLOWREQUEST.fields_by_name['workflow'].message_type = _WORKFLOW
_WORKFLOWRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_WORKFLOWRESPONSE.fields_by_name['workflow'].message_type = _WORKFLOW
_TRANSITIONWORKFLOWSTATUSREQUEST.fields_by_name['workflow'].message_type = _WORKFLOW
_TRANSITIONWORKFLOWSTATUSRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_TRANSITIONWORKFLOWSTATUSRESPONSE.fields_by_name['workflow'].message_type = _WORKFLOW
_QUEUEMISSIONSCANREQUEST.fields_by_name['workflow'].message_type = _WORKFLOW
_QUEUEMISSIONSCANRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_QUEUEMISSIONSCANRESPONSE.fields_by_name['workflow'].message_type = _WORKFLOW
_LISTQUEUEDMISSIONSCANSRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_LISTQUEUEDMISSIONSCANSRESPONSE.fields_by_name['workflows'].message_type = _WORKFLOW
_LISTMISSIONSCANSREQUEST.fields_by_name['workflow'].message_type = _WORKFLOW
_LISTMISSIONSCANSRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_LISTMISSIONSCANSRESPONSE.fields_by_name['workflows'].message_type = _WORKFLOW
_LISTRELATEDMISSIONSCANSBYIDREQUEST.fields_by_name['workflow'].message_type = _WORKFLOW
_LISTRELATEDMISSIONSCANSBYIDRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_LISTRELATEDMISSIONSCANSBYIDRESPONSE.fields_by_name['workflows'].message_type = _WORKFLOW
_QUEUEMISSIONEXPORTREQUEST.fields_by_name['workflow'].message_type = _WORKFLOW
_QUEUEMISSIONEXPORTRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_QUEUEMISSIONEXPORTRESPONSE.fields_by_name['workflow'].message_type = _WORKFLOW
_LISTQUEUEDMISSIONEXPORTSRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_LISTQUEUEDMISSIONEXPORTSRESPONSE.fields_by_name['workflows'].message_type = _WORKFLOW
_LISTMISSIONEXPORTSREQUEST.fields_by_name['workflow'].message_type = _WORKFLOW
_LISTMISSIONEXPORTSRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_LISTMISSIONEXPORTSRESPONSE.fields_by_name['workflows'].message_type = _WORKFLOW
_DELETEWORKFLOWREQUEST.fields_by_name['workflow'].message_type = _WORKFLOW
_DELETEWORKFLOWRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_DELETEWORKFLOWRESPONSE.fields_by_name['workflow'].message_type = _WORKFLOW
DESCRIPTOR.message_types_by_name['Workflow'] = _WORKFLOW
DESCRIPTOR.message_types_by_name['WorkflowRequest'] = _WORKFLOWREQUEST
DESCRIPTOR.message_types_by_name['WorkflowResponse'] = _WORKFLOWRESPONSE
DESCRIPTOR.message_types_by_name['TransitionWorkflowStatusRequest'] = _TRANSITIONWORKFLOWSTATUSREQUEST
DESCRIPTOR.message_types_by_name['TransitionWorkflowStatusResponse'] = _TRANSITIONWORKFLOWSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['QueueMissionScanRequest'] = _QUEUEMISSIONSCANREQUEST
DESCRIPTOR.message_types_by_name['QueueMissionScanResponse'] = _QUEUEMISSIONSCANRESPONSE
DESCRIPTOR.message_types_by_name['ListQueuedMissionScansResponse'] = _LISTQUEUEDMISSIONSCANSRESPONSE
DESCRIPTOR.message_types_by_name['ListMissionScansRequest'] = _LISTMISSIONSCANSREQUEST
DESCRIPTOR.message_types_by_name['ListMissionScansResponse'] = _LISTMISSIONSCANSRESPONSE
DESCRIPTOR.message_types_by_name['ListRelatedMissionScansByIdRequest'] = _LISTRELATEDMISSIONSCANSBYIDREQUEST
DESCRIPTOR.message_types_by_name['ListRelatedMissionScansByIdResponse'] = _LISTRELATEDMISSIONSCANSBYIDRESPONSE
DESCRIPTOR.message_types_by_name['QueueMissionExportRequest'] = _QUEUEMISSIONEXPORTREQUEST
DESCRIPTOR.message_types_by_name['QueueMissionExportResponse'] = _QUEUEMISSIONEXPORTRESPONSE
DESCRIPTOR.message_types_by_name['ListQueuedMissionExportsResponse'] = _LISTQUEUEDMISSIONEXPORTSRESPONSE
DESCRIPTOR.message_types_by_name['ListMissionExportsRequest'] = _LISTMISSIONEXPORTSREQUEST
DESCRIPTOR.message_types_by_name['ListMissionExportsResponse'] = _LISTMISSIONEXPORTSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteWorkflowRequest'] = _DELETEWORKFLOWREQUEST
DESCRIPTOR.message_types_by_name['DeleteWorkflowResponse'] = _DELETEWORKFLOWRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Workflow = _reflection.GeneratedProtocolMessageType('Workflow', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOW,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:Workflow)
  })
_sym_db.RegisterMessage(Workflow)

WorkflowRequest = _reflection.GeneratedProtocolMessageType('WorkflowRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWREQUEST,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:WorkflowRequest)
  })
_sym_db.RegisterMessage(WorkflowRequest)

WorkflowResponse = _reflection.GeneratedProtocolMessageType('WorkflowResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:WorkflowResponse)
  })
_sym_db.RegisterMessage(WorkflowResponse)

TransitionWorkflowStatusRequest = _reflection.GeneratedProtocolMessageType('TransitionWorkflowStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRANSITIONWORKFLOWSTATUSREQUEST,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:TransitionWorkflowStatusRequest)
  })
_sym_db.RegisterMessage(TransitionWorkflowStatusRequest)

TransitionWorkflowStatusResponse = _reflection.GeneratedProtocolMessageType('TransitionWorkflowStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRANSITIONWORKFLOWSTATUSRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:TransitionWorkflowStatusResponse)
  })
_sym_db.RegisterMessage(TransitionWorkflowStatusResponse)

QueueMissionScanRequest = _reflection.GeneratedProtocolMessageType('QueueMissionScanRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUEUEMISSIONSCANREQUEST,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:QueueMissionScanRequest)
  })
_sym_db.RegisterMessage(QueueMissionScanRequest)

QueueMissionScanResponse = _reflection.GeneratedProtocolMessageType('QueueMissionScanResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUEUEMISSIONSCANRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:QueueMissionScanResponse)
  })
_sym_db.RegisterMessage(QueueMissionScanResponse)

ListQueuedMissionScansResponse = _reflection.GeneratedProtocolMessageType('ListQueuedMissionScansResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTQUEUEDMISSIONSCANSRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:ListQueuedMissionScansResponse)
  })
_sym_db.RegisterMessage(ListQueuedMissionScansResponse)

ListMissionScansRequest = _reflection.GeneratedProtocolMessageType('ListMissionScansRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMISSIONSCANSREQUEST,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:ListMissionScansRequest)
  })
_sym_db.RegisterMessage(ListMissionScansRequest)

ListMissionScansResponse = _reflection.GeneratedProtocolMessageType('ListMissionScansResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMISSIONSCANSRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:ListMissionScansResponse)
  })
_sym_db.RegisterMessage(ListMissionScansResponse)

ListRelatedMissionScansByIdRequest = _reflection.GeneratedProtocolMessageType('ListRelatedMissionScansByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTRELATEDMISSIONSCANSBYIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:ListRelatedMissionScansByIdRequest)
  })
_sym_db.RegisterMessage(ListRelatedMissionScansByIdRequest)

ListRelatedMissionScansByIdResponse = _reflection.GeneratedProtocolMessageType('ListRelatedMissionScansByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRELATEDMISSIONSCANSBYIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:ListRelatedMissionScansByIdResponse)
  })
_sym_db.RegisterMessage(ListRelatedMissionScansByIdResponse)

QueueMissionExportRequest = _reflection.GeneratedProtocolMessageType('QueueMissionExportRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUEUEMISSIONEXPORTREQUEST,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:QueueMissionExportRequest)
  })
_sym_db.RegisterMessage(QueueMissionExportRequest)

QueueMissionExportResponse = _reflection.GeneratedProtocolMessageType('QueueMissionExportResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUEUEMISSIONEXPORTRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:QueueMissionExportResponse)
  })
_sym_db.RegisterMessage(QueueMissionExportResponse)

ListQueuedMissionExportsResponse = _reflection.GeneratedProtocolMessageType('ListQueuedMissionExportsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTQUEUEDMISSIONEXPORTSRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:ListQueuedMissionExportsResponse)
  })
_sym_db.RegisterMessage(ListQueuedMissionExportsResponse)

ListMissionExportsRequest = _reflection.GeneratedProtocolMessageType('ListMissionExportsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMISSIONEXPORTSREQUEST,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:ListMissionExportsRequest)
  })
_sym_db.RegisterMessage(ListMissionExportsRequest)

ListMissionExportsResponse = _reflection.GeneratedProtocolMessageType('ListMissionExportsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMISSIONEXPORTSRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:ListMissionExportsResponse)
  })
_sym_db.RegisterMessage(ListMissionExportsResponse)

DeleteWorkflowRequest = _reflection.GeneratedProtocolMessageType('DeleteWorkflowRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEWORKFLOWREQUEST,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:DeleteWorkflowRequest)
  })
_sym_db.RegisterMessage(DeleteWorkflowRequest)

DeleteWorkflowResponse = _reflection.GeneratedProtocolMessageType('DeleteWorkflowResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEWORKFLOWRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:DeleteWorkflowResponse)
  })
_sym_db.RegisterMessage(DeleteWorkflowResponse)



_WORKFLOWAPI = _descriptor.ServiceDescriptor(
  name='WorkflowApi',
  full_name='WorkflowApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1801,
  serialized_end=2619,
  methods=[
  _descriptor.MethodDescriptor(
    name='FindOrCreateWorkflow',
    full_name='WorkflowApi.FindOrCreateWorkflow',
    index=0,
    containing_service=None,
    input_type=_WORKFLOWREQUEST,
    output_type=_WORKFLOWRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TransitionWorkflowStatus',
    full_name='WorkflowApi.TransitionWorkflowStatus',
    index=1,
    containing_service=None,
    input_type=_TRANSITIONWORKFLOWSTATUSREQUEST,
    output_type=_TRANSITIONWORKFLOWSTATUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteWorkflow',
    full_name='WorkflowApi.DeleteWorkflow',
    index=2,
    containing_service=None,
    input_type=_DELETEWORKFLOWREQUEST,
    output_type=_DELETEWORKFLOWRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='QueueMissionExport',
    full_name='WorkflowApi.QueueMissionExport',
    index=3,
    containing_service=None,
    input_type=_QUEUEMISSIONEXPORTREQUEST,
    output_type=_QUEUEMISSIONEXPORTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListQueuedMissionExports',
    full_name='WorkflowApi.ListQueuedMissionExports',
    index=4,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTQUEUEDMISSIONEXPORTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListMissionExports',
    full_name='WorkflowApi.ListMissionExports',
    index=5,
    containing_service=None,
    input_type=_LISTMISSIONEXPORTSREQUEST,
    output_type=_LISTMISSIONEXPORTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='QueueMissionScan',
    full_name='WorkflowApi.QueueMissionScan',
    index=6,
    containing_service=None,
    input_type=_QUEUEMISSIONSCANREQUEST,
    output_type=_QUEUEMISSIONSCANRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListQueuedMissionScans',
    full_name='WorkflowApi.ListQueuedMissionScans',
    index=7,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTQUEUEDMISSIONSCANSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListMissionScans',
    full_name='WorkflowApi.ListMissionScans',
    index=8,
    containing_service=None,
    input_type=_LISTMISSIONSCANSREQUEST,
    output_type=_LISTMISSIONSCANSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListRelatedMissionScansById',
    full_name='WorkflowApi.ListRelatedMissionScansById',
    index=9,
    containing_service=None,
    input_type=_LISTRELATEDMISSIONSCANSBYIDREQUEST,
    output_type=_LISTRELATEDMISSIONSCANSBYIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_WORKFLOWAPI)

DESCRIPTOR.services_by_name['WorkflowApi'] = _WORKFLOWAPI

# @@protoc_insertion_point(module_scope)
